<?php

if (!function_exists('array_column')) {

    /**
     * Returns the values from a single column of the input array, identified by
     * the $columnKey.
     *
     * Optionally, you may provide an $indexKey to index the values in the returned
     * array by the values from the $indexKey column in the input array.
     *
     * @param array $input A multi-dimensional array (record set) from which to pull
     *                     a column of values.
     * @param mixed $columnKey The column of values to return. This value may be the
     *                         integer key of the column you wish to retrieve, or it
     *                         may be the string key name for an associative array.
     * @param mixed $indexKey (Optional) The column to use as the index/keys for
     *                        the returned array. This value may be the integer key
     *                        of the column, or it may be the string key name.
     * @return array
     */
    function array_column($input = null, $columnKey = null, $indexKey = null)
    {
        // Using func_get_args() in order to check for proper number of
        // parameters and trigger errors exactly as the built-in array_column()
        // does in PHP 5.5.
        $argc = func_num_args();
        $params = func_get_args();

        if ($argc < 2) {
            trigger_error("array_column() expects at least 2 parameters, {$argc} given", E_USER_WARNING);
            return null;
        }

        if (!is_array($params[0])) {
            trigger_error('array_column() expects parameter 1 to be array, ' . gettype($params[0]) . ' given', E_USER_WARNING);
            return null;
        }

        if (!is_int($params[1])
            && !is_float($params[1])
            && !is_string($params[1])
            && $params[1] !== null
            && !(is_object($params[1]) && method_exists($params[1], '__toString'))
        ) {
            trigger_error('array_column(): The column key should be either a string or an integer', E_USER_WARNING);
            return false;
        }

        if (isset($params[2])
            && !is_int($params[2])
            && !is_float($params[2])
            && !is_string($params[2])
            && !(is_object($params[2]) && method_exists($params[2], '__toString'))
        ) {
            trigger_error('array_column(): The index key should be either a string or an integer', E_USER_WARNING);
            return false;
        }

        $paramsInput = $params[0];
        $paramsColumnKey = ($params[1] !== null) ? (string) $params[1] : null;

        $paramsIndexKey = null;
        if (isset($params[2])) {
            if (is_float($params[2]) || is_int($params[2])) {
                $paramsIndexKey = (int) $params[2];
            } else {
                $paramsIndexKey = (string) $params[2];
            }
        }

        $resultArray = array();

        foreach ($paramsInput as $row) {

            $key = $value = null;
            $keySet = $valueSet = false;

            if ($paramsIndexKey !== null && array_key_exists($paramsIndexKey, $row)) {
                $keySet = true;
                $key = (string) $row[$paramsIndexKey];
            }

            if ($paramsColumnKey === null) {
                $valueSet = true;
                $value = $row;
            } elseif (is_array($row) && array_key_exists($paramsColumnKey, $row)) {
                $valueSet = true;
                $value = $row[$paramsColumnKey];
            }

            if ($valueSet) {
                if ($keySet) {
                    $resultArray[$key] = $value;
                } else {
                    $resultArray[] = $value;
                }
            }

        }

        return $resultArray;
    }

}


if (!class_exists('verve_options_config')) {

    class verve_options_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (1) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }
        }

        public function initSettings() {
            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            //$this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 2);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**


        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => esc_html__('Section via hook', 'redux-framework-demo'),
                'desc' => esc_html__('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {
            //Background Patterns Reader
            $sample_patterns_path = ReduxFramework::$_dir  . '../../../images/patterns/';
            $sample_patterns_url  = ReduxFramework::$_url  . '../../../images/patterns/';
            $sample_patterns      = array();
            if ( is_dir( $sample_patterns_path ) ) :
              if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) :
                $sample_patterns = array();
                $sample_patterns[] = array( 'alt'=>'none','img' => $sample_patterns_url .'empty/prk_no_pattern.jpg' );

                while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                  if( (stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false) &&  stristr( $sample_patterns_file, '_@2X')===false) {
                    $name = explode(".", $sample_patterns_file);
                    $name = str_replace('.'.end($name), '', $sample_patterns_file);
                    $sample_patterns[] = array( 'alt'=>$name,'img' => $sample_patterns_url . $sample_patterns_file );
                  }
                }
              endif;
            endif;


            $prk_select_font_options=verve_fonts();
            $a = array_column($prk_select_font_options, 'value');
            $b = array_column($prk_select_font_options, 'label');
            $fonts_array=array_combine($a, $b);
            $prk_font_options = get_option('prk_font_plugin_option');
            if (is_array($prk_font_options)) {
                foreach ($prk_font_options as $font) 
                {
                    if ($font['erased']=="false" && !array_key_exists($font['value'],$fonts_array)) 
                    {
                        $fonts_array[$font['value']] = $font['label'];
                    }
                }
            }
            $social_options=array(
                'delicious' => 'Delicious',
                'deviantart' => 'Deviantart',
                'dribbble' => 'Dribbble',
                'facebook-official' => 'Facebook',
                'flickr' => 'Flickr',
                'gplus' => 'Google Plus',
                'instagram' => 'Instagram',
                'linkedin-square' => 'Linkedin',
                'medium' => 'Medium',
                'pinterest' => 'Pinterest',
                'skype' => 'Skype',
                'soundcloud' => 'Soundcloud',
                'twitter' => 'Twitter',
                'vimeo' => 'Vimeo',
                'youtube' => 'Youtube',
                'rss' => 'RSS'
            );

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(esc_html__('Customize &#8220;%s&#8221;', 'redux-framework-demo'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','verve'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','verve'); ?>" />
                <?php endif; ?>

                <h4><?php echo esc_attr($this->theme->display('Name')); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(esc_html__('By %s', 'redux-framework-demo'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(esc_html__('Version %s', 'redux-framework-demo'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . esc_html__('Tags', 'redux-framework-demo') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo esc_attr($this->theme->display('Description')); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . esc_html__('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'redux-framework-demo') . '</p>', esc_html__('http://codex.wordpress.org/Child_Themes', 'redux-framework-demo'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();
            $align_array=array(
                'verve_left_align' => esc_html__('Left', 'verve'),
                'verve_center_align' => esc_html__('Centred', 'verve'),
                'verve_right_align' => esc_html__('Right', 'verve'),
                );

            $sampleHTML = '';
            if (false) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH . '/wp-admin/includes/file.php');
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents('/info-html.html');
            }

            // ACTUAL DECLARATION OF SECTIONS
            $this->sections[] = array(
                'title'     => esc_html__('General', 'redux-framework-demo'),
                'desc'      => esc_html__('', 'redux-framework-demo'),
                'icon'      => 'el-icon-cogs',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                    array(
                'id'=>'verve_responsive',
                'type' => 'switch', 
                'title' => esc_html__('Make the theme layout responsive?', 'verve'),
                'subtitle'=> esc_html__('Make theme adjust to smaller screens.', 'verve'),
                "default"       => 1,
                'compiler' => 'true'
            ),
            array(
                'id'=>'verve_detect_retina',
                'type' => 'switch', 
                'title' => esc_html__('Detect and serve better images on retina screens?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                "default"       => 1,
                'compiler' => 'true'
            ),
            /* array(
                'id'=>'layout',
                'type' => 'select',
                'title' => esc_html__('Layout type?', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => array('wide_verve' => 'Wide','boxed_verve' => 'Boxed'),
                'default' => array('wide_verve' => 'Wide'),
                'compiler' => 'true'
            ), */
            array(
                'id'=>'custom_width',
                'type' => 'text',
                'title' => esc_html__('Maximum content width', 'verve'),
                'subtitle' => esc_html__('Numeric values only.', 'verve'),
                'desc' => esc_html__('How much the center content will stretch. Not applicable on some pages.', 'verve'),
                'validate' => 'numeric',
                'default' => '1280',
                'class' => 'small-text',
                'compiler' => 'true'
            ),
            array(
                'id'=>'ajax_calls',
                'type' => 'switch', 
                'title' => esc_html__('Use Ajax calls to load content?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                'desc' => esc_html__('If on the theme will attempt to load all content using Ajax calls. This will speed up the website page loading process and allow some elements to have smoother transitions.', 'verve'),
                "default"       => 0,
                'compiler' => 'true'
            ),
            array(
                'id'=>'smooth_scroll',
                'type' => 'switch', 
                'title' => esc_html__('Smooth mouse wheel scrolling on Chrome?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                "default"       => 0,
                'compiler' => 'true'
            ),
            array(
                'id'=>'backend_fonts',
                'type' => 'info',
                'desc' => esc_html__('Fonts', 'verve')
            ),
            array(
                'id'=>'font_size',
                'type' => 'slider', 
                'title' => esc_html__('Body font size', 'verve'),
                'subtitle'=> esc_html__('Important: all other font sizes are calculated according to this value.', 'verve'),
                'desc'=> esc_html__('Min: 5, max: 30', 'verve'),
                "default"       => "16",
                "min"       => "5",
                "step"      => "1",
                "max"       => "30",
                'compiler' => 'true'
            ),
            array(
                'id'=>'header_font',
                'type' => 'select',
                'class' => 'prk_hide_default',
                'title' => esc_html__('Headings font', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => $fonts_array,//Must provide key => value pairs for select options
                'default' => array(
                    'value' => 'Cabin:400,600,700,400italic,500',
                    'css' => "'Cabin', sans-serif",
                    'hosted'=> 'google'
                ),
                'compiler' => 'true'
            ),
            array(
                'id'=>'uppercase_headings',
                'type' => 'switch', 
                'title' => esc_html__('Uppercase text that uses the headings font?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                "default"       => 0,
                'compiler' => 'true'
            ),
            array(
                'id'=>'body_font',
                'type' => 'select',
                'title' => esc_html__('Body font', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => $fonts_array,//Must provide key => value pairs for select options
                'default' => array(
                    'value' => 'Droid+Serif:400,700,400italic,700italic',
                    'css' => "Droid Serif",
                    'hosted'=> 'google'
                ),
                'compiler' => 'true'
            ),
            array(
                'id'=>'custom_font',
                'type' => 'select',
                'title' => esc_html__('Extra font', 'verve'), 
                'subtitle' => esc_html__('Optional', 'verve'),
                'desc' => esc_html__('To apply this font to certain elements simply add the CSS class <strong>extra_font</strong>', 'verve'),
                'options' => $fonts_array,//Must provide key => value pairs for select options
                'default' => array(
                    'value' => 'Libre+Baskerville:400,400italic',
                    'css' => "'Libre Baskerville', serif;",
                    'hosted'=> 'google'
                ),
                'compiler' => 'true'
            ),
            array('id'=>'custom_font_style',
                'type' => 'select',
                'title' => esc_html__('Extra font default style', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => array(
                    'normal' => esc_html__('Normal','verve'),
                    'italic' => esc_html__('Italic','verve')),
                'default' => 'italic',
                'compiler' => 'true'
            ),
            array(
                'id'=>'titles_font',
                'type' => 'select',
                'title' => esc_html__('Pages and single posts title font face', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('Default value is Headings font', 'verve'),
                'options' => array(
                    'header_font' => esc_html__('Headings font', 'verve'),
                    'body_font' => esc_html__('Body font', 'verve'),
                    'custom_font' => esc_html__('Extra font', 'verve')),
                'default' => 'header_font',
                'compiler' => 'true'
            ),
            array(
                'id'=>'main_subheadings_font',
                'type' => 'select',
                'title' => esc_html__('Pages and single posts sub-headings font face', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('Default value is Headings font', 'verve'),
                'options' => array(
                    'header_font' => esc_html__('Headings font', 'verve'),
                    'body_font' => esc_html__('Body font', 'verve'),
                    'custom_font' => esc_html__('Extra font', 'verve')),
                'default' => 'body_font',
                'compiler' => 'true'
            ),
            array('id'=>'subheadings_style',
                'type' => 'select',
                'title' => esc_html__('Pages and single posts sub-headings font style', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => array(
                    'normal' => esc_html__('Normal','verve'),
                    'italic' => esc_html__('Italic','verve')),
                'default' => 'italic',
                'compiler' => 'true'
            ),
            array(
                'id'=>'headings_align',
                'type' => 'select',
                'title' => esc_html__('Default pages and single posts title and sub-heading text alignment', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => $align_array,
                'default' => 'verve_center_align',
                'compiler' => 'true'
            ),
            array(
                'id'=>'drop_caps_size',
                'type' => 'slider', 
                'title' => esc_html__('Drop caps size font size (in pixels)', 'verve'),
                'desc'=> esc_html__('Min: 8, max: 150', 'verve'),
                "default"       => "52",
                "min"       => "8",
                "step"      => "1",
                "max"       => "150",
            ),
            array(
                'id'=>'backend_gn_colors',
                'type' => 'info',
                'desc' => esc_html__('Colors: General', 'verve')
            ),
            array(
                'id'=>'use_custom_colors',
                'type' => 'switch', 
                'title' => esc_html__('Use special colors for single posts and portfolio entries?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                "default"       => 1,
                'compiler' => 'true'
                ),
            /*array(
                'id'=>'boxed_image',
                'type' => 'media', 
                'title' => esc_html__('Background image', 'verve'),
                'compiler' => 'true',
                'default'=> array(
                    'url'=>'', 
                    'id'=>'', 
                    'width'=>'', 
                    'height'=>'',
                ),  
                'desc'=> esc_html__('Optional', 'verve'),
                'subtitle' => esc_html__('Only for boxed layouts.', 'verve'),
                'required' => array('layout','equals','boxed_verve'),
                'compiler' => 'true'
                ),*/
            array('id'=>'site_background_color', 
                'type' => 'color', 
                'title' => esc_html__('Site background color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#ffffff', 
                'validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array(
                'id'=>'pattern',
                'type' => 'image_select', 
                'tiles' => true,
                'title' => esc_html__('Site background pattern image', 'verve'),
                'subtitle'=> esc_html__('Optional', 'verve'),
                'desc'=> esc_html__('To add more images place them inside wp-content/themes/verve/images/patterns/', 'verve'),
                'default'       => '',
                'options' => $sample_patterns,
                'compiler' => 'true'
            ),
            array(
                'id'=>'active_color',
                'type' => 'color',
                'title' => esc_html__('Theme active color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#0ab6d1',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
                ),
            array(
                'id'=>'bd_headings_color',
                'type' => 'color',
                'title' => esc_html__('Text headings color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#2F2F2F',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
                ),
            array(
                'id'=>'bd_smallers_color',
                'type' => 'color',
                'title' => esc_html__('Text small headings color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#A5A5A5',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
                ),
            array(
                'id'=>'inactive_color',
                'type' => 'color',
                'title' => esc_html__('Body text color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#404142',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
            ), 
            array( 'id'=>'thumbs_text_color_blog', 
                'type' => 'color', 
                'title' => esc_html__('Thumbnails text color - Blog', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#ffffff', 
                'validate' => 'color', 
                'transparent' => false,
                'compiler' => 'true'
            ),
            array( 'id'=>'background_color_btns_blog', 
                'type' => 'color', 
                'title' => esc_html__('Thumbnails rollover color - Blog (default value)', 'verve'), 
                'subtitle' => esc_html__('Posts with a featured color will override this option', 'verve'), 
                'default' => '#111111', 
                'validate' => 'color', 
                'transparent' => false,
                'compiler' => 'true'
            ),
            array(
                'id'=>'custom_opacity',
                'type' => 'slider', 
                'title' => esc_html__('Custom Background Opacity - Blog rollover effects', 'verve'),
                'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                "default"       => "60",
                "min"       => "0",
                "step"      => "5",
                "max"       => "100",
                'compiler' => 'true'
            ),
            array( 'id'=>'thumbs_text_color', 
                'type' => 'color', 
                'title' => esc_html__('Thumbnails text color - Portfolio', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#ffffff', 
                'validate' => 'color', 
                'transparent' => false,
                'compiler' => 'true'
            ),
            array( 'id'=>'background_color_btns', 
                'type' => 'color', 
                'title' => esc_html__('Thumbnails rollover color - Portfolio (default value)', 'verve'), 
                'subtitle' => esc_html__('Posts with a featured color will override this option', 'verve'), 
                'default' => '#111111', 
                'validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array(
                'id'=>'custom_opacity_folio',
                'type' => 'slider', 
                'title' => esc_html__('Custom Background Opacity - Portfolio rollover effects', 'verve'),
                'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                "default"       => "85",
                "min"       => "0",
                "step"      => "5",
                "max"       => "100",
                'compiler' => 'true'
            ),
            array(
                'id'=>'backend_lb_colors',
                'type' => 'info',
                'desc' => esc_html__('Colors: Textfields, lines and borders', 'verve')
            ),
            array( 
                'id'=>'lines_color', 'type' => 'color', 
                'title' => esc_html__('Lines color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#E8E8E8', 
                'validate' => 'color', 
                'transparent' => false,
                'compiler' => 'true'
            ),
            array( 
                'id'=>'shadow_color', 'type' => 'color', 
                'title' => esc_html__('Shadow color ', 'verve'), 
                'subtitle' => esc_html__('Optional', 'verve'), 
                'default' => '#EAEAEA', 
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
            ),
            array(
                'id'=>'custom_shadow',
                'type' => 'slider', 
                'title' => esc_html__('Shadow opacity', 'verve'),
                'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                "default"       => "5",
                "min"       => "0",
                "step"      => "5",
                "max"       => "100",
                'compiler' => 'true'
            ),
            array(
                'id'=>'background_color',
                'type' => 'color',
                'title' => esc_html__('Textfields background color', 'verve'), 
                'subtitle' => esc_html__('Will also be used on other elements (Ex: pricing tables, progress bars, etc)', 'verve'),
                'default' => '#ffffff',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
            ),
            array(
                'id'=>'inputs_bordercolor',
                'type' => 'color',
                'title' => esc_html__('Textfields border color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#E8E8E8',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
            ),
            array(
                'id'=>'backend_btn_colors',
                'type' => 'info',
                'desc' => esc_html__('Colors and styling: Buttons', 'verve')
            ),
            /*array(
                'id'=>'buttons_style',
                'type' => 'select',
                'title' => esc_html__('Buttons general style?', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => array('solid_buttons' => esc_html__('Always solid colors', 'verve'),'bordered_buttons' => esc_html__('Bordered if mouse is not over', 'verve')),
                'default' => 'bordered_buttons',
                'compiler' => 'true'
            ),*/
            array(
                'id'=>'buttons_font',
                'type' => 'select',
                'title' => esc_html__('Buttons font', 'verve'), 
                'subtitle' => esc_html__('Select the font face to be used for the theme buttons.', 'verve'),
                'desc' => esc_html__('', 'verve'),
                'options' => array(
                    'headings_f' => esc_html__('Headings font', 'verve'),
                    'body_f' => esc_html__('Body font', 'verve'),
                    'custom_f' => esc_html__('Extra font', 'verve')),
                'default' => 'headings_f',
                'compiler' => 'true'
            ),
            array(
                'id'=>'uppercase_buttons',
                'type' => 'switch', 
                'title' => esc_html__('Uppercase text on buttons?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                "default"       => 1,
                'compiler' => 'true'
            ),
            array( 'id'=>'buttons_border', 
                'type' => 'slider', 
                'title' => esc_html__('Ghost buttons border width', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'desc'=> esc_html__('Min: 1, max: 5', 'verve'),
                "default"       => "1",
                "min"       => "0",
                "step"      => "1",
                "max"       => "5",
                'compiler' => 'true'
            ),
            array( 'id'=>'buttons_radius', 
                'type' => 'slider', 
                'title' => esc_html__('Buttons border radius', 'verve'), 
                'subtitle' => esc_html__('Use 0 for squared buttons', 'verve'), 
                'desc'=> esc_html__('Min: 0, max: 40', 'verve'),
                "default"       => "0",
                "min"       => "0",
                "step"      => "1",
                "max"       => "100",
                'compiler' => 'true'
            ),
            array( 'id'=>'buttons_text_color',
                'type' => 'color', 
                'title' => esc_html__('Buttons text color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#FFFFFF', '
                validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array( 'id'=>'theme_buttons_color', 
                'type' => 'color', 
                'title' => esc_html__('Buttons background color', 'verve'), 
                'subtitle' => esc_html__('The alternative background color will be the theme current active color', 'verve'), 
                'default' => '#2F2F2F', 
                'validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array(
                'id'=>'buttons_inner_shadow',
                'type' => 'switch', 
                'title' => esc_html__('Apply inner shadow on buttons?', 'verve'),
                'subtitle'=> esc_html__('Will be placed under the button.', 'verve'),
                "default"       => 0,
                /*'required' => array('buttons_style','equals','solid_buttons'), */
                'compiler' => 'true'
            ),
            array( 'id'=>'slider_text_color', 
                'type' => 'color', 
                'title' => esc_html__('Slider, team members and navigation buttons text color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#FFFFFF', '
                validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array( 'id'=>'buttons_color', 
                'type' => 'color', 
                'title' => esc_html__('Slider, team members and navigation buttons background color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#171717', '
                validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array( 'id'=>'back_to_top_bk', 
                'type' => 'color', 
                'title' => esc_html__('Back to top button background color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#171717', '
                validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array( 'id'=>'back_to_top_color', 
                'type' => 'color', 
                'title' => esc_html__('Back to top button color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'), 
                'default' => '#FFFFFF', '
                validate' => 'color', 
                'transparent' => false, 
                'compiler' => 'true'
            ),
            array(
                'id'=>'backend_gn_colors_oth',
                'type' => 'info',
                'desc' => esc_html__('Colors: Other', 'verve')
            ),
            array(
                'id'=>'preloader_style',
                'type' => 'select',
                'title' => esc_html__('Preloader style', 'verve'), 
                'desc' => esc_html__('', 'verve'),
                'options' => array(
                    'theme_default' => esc_html__('Animated bars', 'verve'),
                    'theme_circles' => esc_html__('Animated circles', 'verve'),
                    'custom_image' => esc_html__('Custom image', 'verve')),
                'default' => 'theme_default',
                'compiler' => 'true',
            ),
            array(
                'id'=>'preloader_color',
                'type' => 'color',
                'title' => esc_html__('Preloader color', 'verve'), 
                'subtitle' => esc_html__('', 'verve'),
                'default' => '#0ab6d1',
                'validate' => 'color',
                'transparent' => false,
                'required' => array('preloader_style','not','custom_image'),
                'compiler' => 'true'
            ),
            array(
                'id'=>'preloader_image',
                'type' => 'media', 
                'title' => esc_html__('Preloader image', 'verve'),
                'compiler' => 'true',
                'default'=> array(
                    'url'=>'', 
                    'id'=>'', 
                    'width'=>'', 
                    'height'=>'',
                ),  
                'desc'=> esc_html__('', 'verve'),
                'subtitle' => esc_html__('Maximum recommended dimensions: 200x200 pixels', 'verve'),
                'required' => array('preloader_style','equals','custom_image'),
            ),
            array(
                'id'=>'preloader_image_retina',
                'type' => 'media', 
                'title' => esc_html__('Preloader image for retina screens', 'verve'),
                'compiler' => 'true',
                'default'=> array(
                    'url'=>'', 
                    'id'=>'', 
                    'width'=>'', 
                    'height'=>'',
                ),  
                'desc'=> esc_html__('', 'verve'),
                'subtitle' => esc_html__('Optional - If used should be the double size of the original preloader image.', 'verve'),
                'required' => array('preloader_style','equals','custom_image'),
            ),
            array(
                'id'=>'featured_header_color',
                'type' => 'color',
                'title' => esc_html__('Featured header text color', 'verve'), 
                'subtitle' => esc_html__('Will be used on posts and portfolio items with featured media', 'verve'),
                'default' => '#ffffff',
                'validate' => 'color',
                'transparent' => false,
                'compiler' => 'true'
                ),
            array(
                'id'=>'bk_color_menu_overlay',
                'type' => 'color',
                'title' => esc_html__('Menu overlay background color', 'verve'), 
                'subtitle' => esc_html__('Will be shown when the hidden menu is visible', 'verve'),
                'default' => '#191919',
                'validate' => 'color',
                'transparent' => false,
                //'required' => array('menu_display','equals','st_hidden_menu'), 
                'compiler' => 'true'
            ),
            array(
                'id'=>'opacity_menu_overlay',
                'type' => 'slider', 
                'title' => esc_html__('Menu overlay opacity', 'verve'),
                'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                "default"       => "85",
                "min"       => "0",
                "step"      => "5",
                "max"       => "100",
                //'required' => array('menu_display','equals','st_hidden_menu'), 
                'compiler' => 'true'
            ),
            array(
                'id'=>'backend_sdb_sidebars',
                'type' => 'info',
                'desc' => esc_html__('Sidebars', 'verve')
            ), 
            array(
                'id'=>'right_sidebar',
                'type' => 'switch', 
                'title' => esc_html__('Display right sidebar on pages and posts by default?', 'verve'),
                'subtitle'=> esc_html__('', 'verve'),
                "default"       => 1,
                'compiler' => 'true'
            ),
            ));
            $this->sections[] = array(
            'icon' => 'el-icon-star',
            'title' => esc_html__('Branding & Logo Bar', 'verve'),
            'fields' => array(
                array(
                    'id'=>'logo_align',
                    'type' => 'select',
                    'title' => esc_html__('Logo bar display', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'st_logo_on_left' => esc_html__('Left side with menu hidden', 'verve'),
                        'st_logo_on_right' => esc_html__('Right side with menu hidden', 'verve'),
                        'st_menu_on_left' => esc_html__('Left side with menu always visible', 'verve'),
                        'st_menu_on_right' => esc_html__('Right side with menu always visible', 'verve'),
                        'st_no_menu' => esc_html__('Do not display any bar', 'verve'),
                    ),
                    'default' => 'st_logo_on_left',
                    'compiler' => 'true'
                ),
                array( 'id'=>'logo_bar_width', 
                    'type' => 'text', 
                    'title' => esc_html__('Logo bar width', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '122', 
                    'class' => 'small-text',
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                 array( 'id'=>'logo_up_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Logo bar up text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#FFFFFF', 
                    'validate' => 'color', 
                    'transparent' => false, 
                    //'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')),
                ),
                array( 'id'=>'logo_active_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Logo bar active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#0ab6d1', 
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array(
                    'id'=>'background_color_logo_bar',
                    'type' => 'color',
                    'title' => esc_html__('Logo bar background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#111111',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true',
                    //'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array(
                    'id'=>'logo_bar_opacity',
                    'type' => 'slider', 
                    'title' => esc_html__('Logo bar background opacity', 'verve'),
                    'desc'=> esc_html__('If different from 100 website content will appear behind the logo bar', 'verve'),
                    "default"       => "100",
                    "min"       => "0",
                    "step"      => "1",
                    "max"       => "100",
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array(
                    'id'=>'menu_text',
                    'type' => 'text',
                    'title' => esc_html__('Logo bar menu help text', 'verve'), 
                    'subtitle' => esc_html__('Space is limited so use very few text.', 'verve'),
                    'default' => esc_html__('MENU','verve'),
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array(
                    'id'=>'fullscreen_btn',
                    'type' => 'switch', 
                    'title' => esc_html__('Show fullscreen button', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array( 'id'=>'logo_top_margin', 
                    'type' => 'text', 
                    'title' => esc_html__('Logo bar top padding', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '13', 
                    'class' => 'small-text',
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array( 'id'=>'logo_sides_margin', 
                    'type' => 'text', 
                    'title' => esc_html__('Logo bar horizontal padding', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '6', 
                    'class' => 'small-text',
                    'required' => array('logo_align','equals',array('st_logo_on_left','st_logo_on_right')), 
                ),
                array(
                    'id'=>'logo',
                    'type' => 'media', 
                    'title' => esc_html__('Logo', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>get_template_directory_uri().'/images/logo.png', 
                        'id'=>'', 
                        'width'=>'160', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('', 'verve'),
                    'subtitle' => esc_html__('Optional - Leave blank if logo is not needed.', 'verve'),
                    ),
                array(
                    'id'=>'logo_retina',
                    'type' => 'media', 
                    'title' => esc_html__('Logo for retina screens', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>get_template_directory_uri().'/images/logo-retina.png', 
                        'id'=>'', 
                        'width'=>'320', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('', 'verve'),
                    'subtitle' => esc_html__('Optional - If used should be the double size of the original logo image.', 'verve'),
                ),
                array(
                    'id'=>'logo_collapsed',
                    'type' => 'media', 
                    'title' => esc_html__('Logo - Mobile mode', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>get_template_directory_uri().'/images/persistent-regular.png', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('', 'verve'),
                    'subtitle' => esc_html__('Maximum recommended height is 44 pixels', 'verve'),
                    ),
                array(
                    'id'=>'logo_collapsed_retina',
                    'type' => 'media', 
                    'title' => esc_html__('Logo retina screens - Mobile mode', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>get_template_directory_uri().'/images/persistent-retina.png', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('', 'verve'),
                    'subtitle' => esc_html__('Optional - If used should be the double size of the original logo image.', 'verve'),
                ),
                array( 'id'=>'logo_collapsed_top_margin', 
                    'type' => 'text', 
                    'title' => esc_html__('Logo top margin - Mobile mode', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '3', 
                    'class' => 'small-text',
                ),
                array(
                    'id'=>'favicon',
                    'type' => 'media', 
                    'title' => esc_html__('Favicon image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>get_template_directory_uri().'/images/favicon.ico', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Should have .ico as file extension.', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-list',
            'title' => esc_html__('Menu Bar', 'verve'),
            'fields' => array(
                array(
                    'id'=>'resp_break',
                    'type' => 'text', 
                    'title' => esc_html__('Minimum window width before activating mobile mode', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('Mobile mode will always be activated on screens with less than 768px.', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '870', 
                    'class' => 'small-text'
                ),
                array( 'id'=>'menu_vertical', 
                    'type' => 'text', 
                    'title' => esc_html__('Menu bar width', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '320', 
                    'class' => 'small-text',
                ),
                array(
                    'id'=>'menu_with_page',
                    'type' => 'switch', 
                    'title' => esc_html__('Show page when menu button is clicked?', 'verve'),
                    'subtitle'=> esc_html__('Menu width will be forced to 100%.', 'verve'),
                    "default"       => 0,
                ),
                array(
                    'id'=>'overlay_page_id',
                    'type' => 'select',
                    'data' => 'pages',
                    'title' => esc_html__('Select page that will be shown when the menu button is clicked', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    "default"       => '',
                    'required' => array('menu_with_page','equals','1'), 
                ),
                array(
                    'id'=>'background_color_menu_bar',
                    'type' => 'color',
                    'title' => esc_html__('Menu bar background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#171717',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'background_image_menu_bar',
                    'type' => 'media', 
                    'title' => esc_html__('Menu bar background image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>'', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Optional', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                ),
                array(
                    'id'=>'border_menu_bar',
                    'type' => 'color',
                    'title' => esc_html__('Menu bar right border color', 'verve'), 
                    'subtitle' => esc_html__('Optional', 'verve'),
                    'default' => '#171717',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'menu_align',
                    'type' => 'select',
                    'title' => esc_html__('Menu text alignment', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => $align_array,
                    'default' => 'verve_left_align',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'menu_hover_anim',
                    'type' => 'select',
                    'title' => esc_html__('Menu buttons hover animation', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'color' => esc_html__('Change color', 'verve'),
                        'margin' => esc_html__('Slide up', 'verve'),
                    ),
                    'default' => 'color',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'color_menu_overlay',
                    'type' => 'color',
                    'title' => esc_html__('Menu footer text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#FFFFFF',
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('menu_display','equals','st_hidden_menu'), 
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_footer_menu',
                    'type' => 'select',
                    'data' => 'sidebars',
                    'title' => esc_html__('Extra sidebar ID', 'verve'),
                    'subtitle' => esc_html__('Sidebars can be created under Appearance>Manage Sidebars', 'verve'),
                    'desc' => esc_html__('This sidebar will be used as a footer.', 'verve'),
                    'default' => '',
                    //'required' => array('show_hidden_sidebar','equals','1'),
                ),
                array(
                    'id'=>'overlay_footer_text',
                    'type' => 'editor',
                    'title' => esc_html__('Menu footer text', 'verve'), 
                    'subtitle' => esc_html__('Space is limited so use very few text.', 'verve'),
                    'default' => esc_html__('','verve'),
                    'editor_options'   => array(
                        'teeny'            => true,
                        'textarea_rows'    => 1,
                        'media_buttons'    => false,
                        'tinymce'          => false
                    ),
                    //'required' => array('menu_display','equals','st_hidden_menu'), 
                ),
                array(
                    'id'=>'backend_widgets_mainmenu_buttons',
                    'type' => 'info',
                    'desc' => esc_html__('Main menu: parent buttons style', 'verve')
                ),
                array('id'=>'menu_padding',
                    'type' => 'slider', 
                    'title' => esc_html__('Parent menu buttons height (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 4, max: 80', 'verve'),
                    "default"   => "32",
                    "min"       => "4",
                    "step"      => "1",
                    "max"       => "80",
                ),
                array( 'id'=>'mn_buttons_border', 
                    'type' => 'color', 
                    'title' => esc_html__('Buttons border color', 'verve'), 
                    'subtitle' => esc_html__('Leave blank if you do not need any border', 'verve'), 
                    'default' => '#000000', '
                    validate' => 'color', 
                    'transparent' => false, 
                    'compiler' => 'true',
                    'required' => array('logo_align','equals',array('st_menu_on_left','st_menu_on_right')), 
                ),
                array(
                    'id'=>'menu_font',
                    'type' => 'select',
                    'title' => esc_html__('Menu buttons font face', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('Default value is Headings font', 'verve'),
                    'options' => array(
                        'header_font' => esc_html__('Headings font', 'verve'),
                        'body_font' => esc_html__('Body font', 'verve'),
                        'custom_font' => esc_html__('Extra font', 'verve')),
                    'default' => 'header_font',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'menu_font_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Parent menu buttons font size (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 8, max: 50', 'verve'),
                    "default"       => "22",
                    "min"       => "8",
                    "step"      => "1",
                    "max"       => "50",
                ),
                array(
                    'id'=>'menu_parent_style',
                    'type' => 'select',
                    'title' => esc_html__('Parent menu buttons font style?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array('normal' => esc_html__('Normal','verve'),'italic' => esc_html__('Italic','verve')),
                    'default' => 'normal',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'menu_font_weight',
                    'type' => 'select',
                    'title' => esc_html__('Parent menu buttons font weight?', 'verve'), 
                    'subtitle' => esc_html__('Fonts usually support only certain sizes.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        '100' => '100',
                        '200' => '200',
                        '300' => '300',
                        '400' => esc_html__('Normal','verve'),
                        '500' => '500',
                        '600' => '600',
                        '700' => esc_html__('Bold','verve'),
                        '900' => esc_html__('Bolder','verve')
                    ),
                    'default' => '600',
                    'compiler' => 'true'
                ),
                array( 'id'=>'menu_active_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Parent menu buttons active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#0ab6d1', 
                    'validate' => 'color',
                    'transparent' => false,
                ),
                array( 'id'=>'menu_up_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Parent menu buttons text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#FFFFFF', 
                    'validate' => 'color', 
                    'transparent' => false, 
                ),
                array(
                    'id'=>'menu_icons_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Parent menu buttons icons size (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 4, max: 50', 'verve'),
                    "default"       => "16",
                    "min"       => "4",
                    "step"      => "1",
                    "max"       => "50",
                ),
                array('id'=>'backend_widgets_submenu_buttons',
                    'type' => 'info',
                    'desc' => esc_html__('Main menu: sub-menu buttons style', 'verve')
                ),
                array(
                    'id'=>'menu_sub_padding',
                    'type' => 'slider', 
                    'title' => esc_html__('Sub-menu buttons height (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 4, max: 80', 'verve'),
                    "default"   => "24",
                    "min"       => "4",
                    "step"      => "1",
                    "max"       => "80",
                ),
                array('id'=>'submenu_font_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Sub-menu buttons font size (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 8, max: 50', 'verve'),
                    "default"       => "18",
                    "min"       => "8",
                    "step"      => "1",
                    "max"       => "50",
                ),
                array(
                    'id'=>'submenu_font_weight',
                    'type' => 'select',
                    'title' => esc_html__('Sub-menu buttons font weight?', 'verve'), 
                    'subtitle' => esc_html__('Fonts usually support only certain sizes.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array('100' => '100','200' => '200','300' => '300','400' => esc_html__('Normal','verve'),'500' => '500','600' => '600','700' => esc_html__('Bold','verve'),'900' => esc_html__('Bolder','verve')),
                    'default' => '600',
                    'compiler' => 'true'
                ),
                array( 'id'=>'submenu_active_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Sub-menu buttons active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#0ab6d1', 
                    'validate' => 'color',
                    'transparent' => false,
                ),
                array( 'id'=>'submenu_text_color', 
                    'type' => 'color', 
                    'title' => esc_html__('Sub-menu buttons text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'default' => '#969696', 
                    'validate' => 'color', 
                    'transparent' => false, 
                ),
                array(
                    'id'=>'submenu_icons_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Sub-menu buttons icons size (in pixels)', 'verve'),
                    'desc'=> esc_html__('Min: 4, max: 50', 'verve'),
                    "default"       => "12",
                    "min"       => "4",
                    "step"      => "1",
                    "max"       => "50",
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-indent-right',
            'title' => esc_html__('Hidden Sidebar', 'verve'),
            'fields' => array(
                array(
                    'id'=>'show_hidden_sidebar',
                    'type' => 'switch', 
                    'title' => esc_html__('Show hidden sidebar?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 0,
                ),
                array(
                    'id'=>'sidebar_icon_set',
                    'type' => 'select',
                    'title' => esc_html__('Sidebar icon set?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'awesome' => esc_html__('Font Awesome Icons', 'verve'),
                        'mdi' => esc_html__('Material Design Icons', 'verve')
                    ),
                    'default' => 'awesome',
                    'required' => array('show_hidden_sidebar','equals','1'), 
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_icon',
                    'type' => 'select',
                    'title' => esc_html__('Select icon', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'data' => 'awesome-icons',
                    'default' => 'verve_fa-info',
                    'required' => array('sidebar_icon_set','equals','awesome'), 
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_icon_2',
                    'type' => 'select',
                    'title' => esc_html__('Select icon', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'data' => 'mdi-icons',
                    'default' => 'mdi-chevron-double-right',
                    'required' => array('sidebar_icon_set','equals','mdi'), 
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_icon_size',                 
                    'type' => 'text',
                    'title' => esc_html__('Icon size', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'validate' => 'numeric',
                    'default' => '28',
                    'class' => 'small-text',
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_width',
                    'type' => 'text',
                    'title' => esc_html__('Hidden sidebar width', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'),
                    'desc' => esc_html__('Default value is 400.', 'verve'),
                    'validate' => 'numeric',
                    'default' => '400',
                    'class' => 'small-text',
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                array('id'=>'hidden_font_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Hidden sidebar body font size', 'verve'),
                    'desc'=> esc_html__('Min: 6, max: 50', 'verve'),
                    "default"       => "14",
                    "min"       => "6",
                    "step"      => "1",
                    "max"       => "50",
                    'required' => array('show_hidden_sidebar','equals','1'),
                ),
                array(
                    'id'=>'sidebar_align',
                    'type' => 'select',
                    'title' => esc_html__('Hidden sidebar text alignment?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => $align_array,
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'default' => 'verve_left_align',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'background_image_sidebar',
                    'type' => 'media', 
                    'title' => esc_html__('Hidden sidebar background image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>'', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Optional', 'verve'),
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'subtitle' => esc_html__('', 'verve'),
                ),
                array(
                    'id'=>'background_color_sidebar',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#171717',
                    'validate' => 'color',
                    'transparent' => false,
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'active_color_sidebar',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#FFFFFF',
                    'validate' => 'color',
                    'transparent' => false,
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                    ),
                array(
                    'id'=>'body_color_sidebar',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#BBBBBB',
                    'validate' => 'color',
                    'transparent' => false,
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true' 
                    ),
                array(
                    'id'=>'lines_color_sidebar',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar lines color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#252525',
                    'validate' => 'color',
                    'transparent' => false,
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true' 
                    ),
                array(
                    'id'=>'sidebar_footer_id',
                    'type' => 'select',
                    'data' => 'sidebars',
                    'title' => esc_html__('Extra sidebar ID', 'verve'),
                    'subtitle' => esc_html__('Sidebars can be created under Appearance>Manage Sidebars', 'verve'),
                    'desc' => esc_html__('This sidebar will be used as a footer.', 'verve'),
                    'required' => array('show_hidden_sidebar','equals','1'),
                    'default' => '',
                ),
                /*array(
                    'id'=>'opacity_sidebar_overlay',
                    'type' => 'slider', 
                    'title' => esc_html__('Content overlay opacity', 'verve'),
                    'subtitle' => esc_html__('Applicable only for when the hidden sidebar is visible.', 'verve'),
                    'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                    "default"       => "25",
                    "min"       => "0",
                    "step"      => "5",
                    "max"       => "100",
                    'compiler' => 'true',
                    'required' => array('show_hidden_sidebar','equals','1'),
                ),*/
            )
        );
        $this->sections[] = array(
                'icon' => 'el-icon-website',
                'title' => esc_html__('Mobile Menu', 'verve'),
                'fields' => array(
                array(
                    'id'=>'append_mobile_logo',
                    'type' => 'select',
                    'title' => esc_html__('Show logo on mobile bar?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'no' => esc_html__('No', 'verve'),
                        'mobile_logo_bef' => esc_html__('Yes', 'verve'),
                        'mobile_logo_aft' => esc_html__('Yes, mobile mode logo', 'verve')
                    ),
                    'default' => 'mobile_logo_aft',
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'right_bar_align',
                    'type' => 'select',
                    'title' => esc_html__('Mobile menu bar text alignment?', 'verve'), 
                    'subtitle' => esc_html__('Default value is centred.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => $align_array,
                    'default' => 'verve_left_align',
                    'compiler' => 'true'
                ), 
                array(
                    'id'=>'background_image_right_bar',
                    'type' => 'media', 
                    'title' => esc_html__('Mobile menu bar background image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>'', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Optional', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                ),
                array(
                    'id'=>'background_color_right_bar',
                    'type' => 'color',
                    'title' => esc_html__('Mobile menu bar background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#111111',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'active_color_right_bar',
                    'type' => 'color',
                    'title' => esc_html__('Mobile menu bar active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                    ),
                array(
                    'id'=>'body_color_right_bar',
                    'type' => 'color',
                    'title' => esc_html__('Mobile menu bar text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#969696',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true' 
                    ),
                array(
                    'id'=>'opacity_mobile_overlay',
                    'type' => 'slider', 
                    'title' => esc_html__('Content overlay opacity', 'verve'),
                    'subtitle' => esc_html__('Applicable only for when the hidden sidebar is visible.', 'verve'),
                    'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                    "default"       => "75",
                    "min"       => "0",
                    "step"      => "5",
                    "max"       => "100",
                    'compiler' => 'true'
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-indent-right',
            'title' => esc_html__('Persistent Menu', 'verve'),
            'fields' => array(
                /*array(
                    'id'=>'sidebar_width',
                    'type' => 'text',
                    'title' => esc_html__('Sharing bar width', 'verve'), 
                    'subtitle' => esc_html__('In pixels.', 'verve'),
                    'desc' => esc_html__('Default value is 62.', 'verve'),
                    'validate' => 'numeric',
                    'default' => '62',
                    'class' => 'small-text',
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'sidebar_align',
                    'type' => 'select',
                    'title' => esc_html__('Hidden sidebar text alignment?', 'verve'), 
                    'subtitle' => esc_html__('Default value is centred.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => $align_array,
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'default' => 'verve_center_align',
                    'compiler' => 'true'
                ),*/
                /*array(
                    'id'=>'background_image_sidebar',
                    'type' => 'media', 
                    'title' => esc_html__('Hidden sidebar background image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>'', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Optional', 'verve'),
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'subtitle' => esc_html__('', 'verve'),
                ),*/
                array(
                    'id'=>'persistent_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Enable persistent menu on blog single posts', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'persistent_folio',
                    'type' => 'switch', 
                    'title' => esc_html__('Enable persistent menu on portfolio single posts', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'background_color_prst',
                    'type' => 'color',
                    'title' => esc_html__('Persistent menu bar background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#F4F4F4',
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'border_color_prst',
                    'type' => 'color',
                    'title' => esc_html__('Persistent menu bar bottom border color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#EAEAEA',
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                ),
                /*array(
                    'id'=>'active_color_sidebar',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true'
                    ),*/
                array(
                    'id'=>'body_color_prst',
                    'type' => 'color',
                    'title' => esc_html__('Hidden sidebar text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#191919',
                    'validate' => 'color',
                    'transparent' => false,
                    //'required' => array('show_hidden_sidebar','equals','1'),
                    'compiler' => 'true' 
                    ),
                /*array(
                    'id'=>'opacity_sidebar_overlay',
                    'type' => 'slider', 
                    'title' => esc_html__('Content overlay opacity', 'verve'),
                    'subtitle' => esc_html__('Applicable only for when the hidden sidebar is visible.', 'verve'),
                    'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                    "default"       => "25",
                    "min"       => "0",
                    "step"      => "5",
                    "max"       => "100",
                    'compiler' => 'true',
                    //'required' => array('show_hidden_sidebar','equals','1'),
                ),*/
            )
        );
        $this->sections[] = array(
            'icon' => 'el el-chevron-up',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Header Section', 'verve'),
            'fields' => array(
                array(
                    'id'=>'header_page',
                    'type' => 'switch', 
                    'title' => esc_html__('Add special page content before the content', 'verve'),
                    'subtitle'=> esc_html__('Create a specific page to be used here', 'verve'),
                    "default"       => 0,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'header_page_id',
                    'type' => 'select',
                    'data' => 'pages',
                    'title' => esc_html__('Page to be displayed before outputting the current page?', 'verve'),
                    'subtitle' => esc_html__('Content will be added before the page content', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    "default"       => '',
                    'required' => array('header_page','equals','1'), 
                ),
                array(
                    'id'=>'header_as_menu',
                    'type' => 'switch', 
                    'title' => esc_html__('Use header section as menu?', 'verve'),
                    'subtitle'=> esc_html__('If yes, elements with forced heights will consider the header section height', 'verve'),
                    "default"       => 1,
                    'compiler' => 'true',
                    'required' => array('header_page','equals','1'), 
                ),
            ),
        );   
        $this->sections[] = array(
            'icon' => 'el el-chevron-down',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Footer Section', 'verve'),
            'fields' => array(
                array(
                    'id'=>'use_footer',
                    'type' => 'switch', 
                    'title' => esc_html__('Display footer?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'footer_reveal',
                    'type' => 'switch', 
                    'title' => esc_html__('Make footer position fixed?', 'verve'),
                    'subtitle'=> esc_html__('If yes it will create a reveal effect on the footer.', 'verve'),
                    "default"       => 0,
                ),
                array('id'=>'footer_font_size',
                    'type' => 'slider', 
                    'title' => esc_html__('Footer body font size', 'verve'),
                    'desc'=> esc_html__('Min: 6, max: 50', 'verve'),
                    "default"       => "13",
                    "min"       => "6",
                    "step"      => "1",
                    "max"       => "50",
                ),
                array(
                    'id'=>'titles_color_footer',
                    'type' => 'color',
                    'title' => esc_html__('Footer titles and links text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#FFFFFF',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'body_color_footer',
                    'type' => 'color',
                    'title' => esc_html__('Footer text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#EAEAEA',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'footer_border_color',
                    'type' => 'color',
                    'title' => esc_html__('Footer top border color', 'verve'), 
                    'subtitle' => esc_html__('Leave blank for no border', 'verve'),
                    'default' => '#111111',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'background_color_footer',
                    'type' => 'color',
                    'title' => esc_html__('Footer background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#111111',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'bk_image_footer',
                    'type' => 'media', 
                    'title' => esc_html__('Footer background image', 'verve'),
                    'compiler' => 'true',
                    'default'=> array(
                        'url'=>'', 
                        'id'=>'', 
                        'width'=>'', 
                        'height'=>'',
                    ),  
                    'desc'=> esc_html__('Optional', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'compiler' => 'true'
                    ),
                array(
                    'id'=>'footer_image_align',
                    'type' => 'select',
                    'title' => esc_html__('Background image position', 'verve'), 
                    'subtitle' => esc_html__('How the image will be aligned vertically', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'top' => esc_html__('Top','verve'),
                        'center' => esc_html__('Center','verve'),
                        'bottom' => esc_html__('Bottom','verve'),
                    ),
                    'default' => 'top',
                    'required' => array('bk_image_footer','not',''), 
                    'compiler' => 'true'
                ),
                /*array(
                    'id'=>'pattern_footer',
                    'type' => 'image_select', 
                    'tiles' => true,
                    'title' => esc_html__('Footer background pattern images', 'verve'),
                    'subtitle'=> esc_html__('Optional', 'verve'),
                    'desc'=> esc_html__('To add more images place them inside wp-content/themes/verve/images/patterns/', 'verve'),
                    'default'       => '',
                    'options' => $sample_patterns,
                ),*/
                array(
                    'id'=>'bottom_page',
                    'type' => 'switch', 
                    'title' => esc_html__('Add special page content before footer widgets?', 'verve'),
                    'subtitle'=> esc_html__('Create a specific page to be used here', 'verve'),
                    "default"       => 0,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'bottom_page_id',
                    'type' => 'select',
                    'data' => 'pages',
                    'title' => esc_html__('Page to be displayed before footer widgets?', 'verve'),
                    'subtitle' => esc_html__('Content will be added before the footer widgets.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    "default"       => '',
                    'required' => array('bottom_page','equals','1'), 
                ),
                array(
                    'id'=>'bottom_page_after',
                    'type' => 'switch', 
                    'title' => esc_html__('Add special page content after footer widgets?', 'verve'),
                    'subtitle'=> esc_html__('Create a specific page to be used here', 'verve'),
                    "default"       => 0,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'bottom_page_after_id',
                    'type' => 'select',
                    'data' => 'pages',
                    'title' => esc_html__('Page to be displayed after footer widgets?', 'verve'),
                    'subtitle' => esc_html__('Content will be added after the footer widgets.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    "default"       => '',
                    'required' => array('bottom_page_after','equals','1'), 
                ),
                array(
                    'id'=>'bottom_sidebar',
                    'type' => 'switch', 
                    'title' => esc_html__('Display footer sidebar?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'widgets_nr',
                    'type' => 'select',
                    'title' => esc_html__('Number of widgets per row?', 'verve'), 
                    'subtitle' => esc_html__('Default value is Three.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'small-12' => esc_html__('One','verve'),
                        'small-6' => esc_html__('Two','verve'),
                        'small-4' => esc_html__('Three','verve'),
                        'small-3' => esc_html__('Four','verve'),
                        'small-2' => esc_html__('Six','verve'),
                    ),
                    'default' => 'small-4',
                    'required' => array('bottom_sidebar','equals','1'), 
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'footer_text',
                    'type' => 'editor',
                    'title' => esc_html__('After footer text (center or left aligned)', 'verve'), 
                    'subtitle' => esc_html__('Space is limited so use few text.', 'verve'),
                    'default' => esc_html__('','verve'),
                    'editor_options'   => array(
                        'teeny'            => true,
                        'textarea_rows'    => 1,
                        'media_buttons'    => false,
                        'tinymce'          => false
                    )
                ),
                array(
                    'id'=>'footer_text_extra',
                    'type' => 'editor',
                    'title' => esc_html__('Extra after footer text (right aligned)', 'verve'), 
                    'subtitle' => esc_html__('Space is limited so use few text.', 'verve'),
                    'default' => esc_html__('','verve'),
                    'editor_options'   => array(
                        'teeny'            => true,
                        'textarea_rows'    => 1,
                        'media_buttons'    => false,
                        'tinymce'          => false
                    )
                ),
                array(
                    'id'=>'footer_text_background_color',
                    'type' => 'color',
                    'title' => esc_html__('After footer text background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#111111',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
            )
        );

        $this->sections[] = array(
            'icon' => 'el-icon-calendar',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Blog', 'verve'),
            'fields' => array(
                array(
                    'id'=>'archives_type',
                    'type' => 'select',
                    'title' => esc_html__('Blog archives page template?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'classic' => 'Classic - Big media with post information always visible',
                        'grid' => 'Image grid - Image focused with info displayed on rollover',
                        'masonry' => 'Masonry - Mosaic with post information always visible',
                        'stacked' => 'Modern - Plain text with image reveal on rollover',
                    ),
                    'default' => 'classic'
                ),
                array(
                    'id'=>'posts_bk_color',
                    'type' => 'color',
                    'title' => esc_html__('Posts box background color', 'verve'), 
                    'subtitle' => esc_html__('Will be used on Masonry and Classic blog feeds', 'verve'),
                    'default' => '#FDFDFD',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'custom_width_blog',
                    'type' => 'text',
                    'title' => esc_html__('Maximum blog content width', 'verve'),
                    'subtitle' => esc_html__('In pixels.', 'verve'),
                    'desc' => esc_html__("Will be applied only to blog pages/posts that don't have a right sidebar.", 'verve'),
                    'validate' => 'numeric',
                    'default' => '1080',
                    'class' => 'small-text'
                    ),
                array(
                    'id'=>'header_align_blog',
                    'type' => 'select',
                    'title' => esc_html__('Single posts default featured header text position', 'verve'),
                    'subtitle' => esc_html__('Applies only to posts with featured media', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                    'topped_content' => esc_html__('Top','verve'),
                    'middled_content' => esc_html__('Middle','verve'),
                    'bottomed_content' => esc_html__('Bottom','verve')),//Must provide key => value pairs for select options
                    'default' => 'bottomed_content'
                    ),
                array(
                    'id'=>'autoplay_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Play slideshow on single posts?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ), 
                array( 'id'=>'delay_blog', 
                    'type' => 'text', 
                    'title' => esc_html__('Slideshow delay in miliseconds', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '6500', 
                    'class' => 'small-text' 
                ),
                array(
                    'id'=>'uppercase_blog_headings',
                    'type' => 'switch', 
                    'title' => esc_html__('Uppercase posts meta information?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'show_date_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Show dates on blog?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'minread_blog',
                    'type' => 'switch', 
                    'title' => __('Show "Minutes Read" text on blog?', 'verve'),
                    'subtitle'=> __('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'postedby_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Show "Posted by" text on blog?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'categoriesby_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Show post categories text on blog?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'show_blog_nav',
                    'type' => 'switch', 
                    'title' => esc_html__('Show previous and next posts link?', 'verve'),
                    'subtitle'=> esc_html__('Will be shown under the post content.', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'related_posts',
                    'type' => 'switch', 
                    'title' => esc_html__('Show related posts?', 'verve'),
                    'subtitle'=> esc_html__('Will be shown under the post comments section.', 'verve'),
                    "default"       => 1,
                ),
                /*array(
                    'id'=>'related_posts_bk_color',
                    'type' => 'color',
                    'title' => esc_html__('Related posts background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'related_posts_border_color',
                    'type' => 'color',
                    'title' => esc_html__('Related posts border color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),*/
                array(
                    'id'=>'related_author',
                    'type' => 'switch', 
                    'title' => esc_html__('Show author info under post?', 'verve'),
                    'subtitle'=> esc_html__('Will be shown under the post content.', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'backend_bl_sharing',
                    'type' => 'info',
                    'desc' => esc_html__('Social Sharing', 'verve')
                ),
                array(
                    'id'=>'share_blog',
                    'type' => 'switch', 
                    'title' => esc_html__('Show sharing buttons?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'share_blog_fb',
                    'type' => 'checkbox',
                    'required' => array('share_blog','equals','1'), 
                    'title' => esc_html__('Facebook', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_blog_goo',
                    'type' => 'checkbox',
                    'required' => array('share_blog','equals','1'), 
                    'title' => esc_html__('Google +', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_blog_pin',
                    'type' => 'checkbox',
                    'required' => array('share_blog','equals','1'), 
                    'title' => esc_html__('Pinterest', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_blog_twt',
                    'type' => 'checkbox',
                    'required' => array('share_blog','equals','1'), 
                    'title' => esc_html__('Twitter', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_blog_email',
                    'type' => 'checkbox',
                    'required' => array('share_blog','equals','1'), 
                    'title' => esc_html__('Share By Email', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
            )
        );

        $this->sections[] = array(
            'icon' => 'el-icon-camera',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Portfolio', 'verve'),
            'fields' => array(
                array(
                    'id'=>'archives_ptype',
                    'type' => 'select',
                    'title' => esc_html__('Portfolio archives page template?', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'grid' => esc_html__('Grid with horizontal rectangular images','verve'),
                        'grid_vertical' => esc_html__('Grid with vertical rectangular images','verve'),
                        'squares' => esc_html__('Grid with squared images','verve'),
                        'masonry' => esc_html__('Grid without image crop - Masonry','verve')
                    ),
                    'default' => 'grid'
                ), 
                array(
                    'id'=>'portfolio_layout',
                    'type' => 'select',
                    'title' => esc_html__('Default single portfolio posts layout', 'verve'), 
                    'subtitle' => esc_html__('Can be overriden individually for each post', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'options' => array(
                        'half' => esc_html__('Split - post info panel on the right side','verve'),
                        'wide' => esc_html__('Boxed - featured slider with margins','verve'),
                        'wideout' => esc_html__('Full width - featured slider without margins','verve'),
                        'custom' => esc_html__('Custom layout','verve')),
                    'default' => array('wideout' => 'Full width')
                    ),
                array(
                    'id'=>'autoplay_portfolio',
                    'type' => 'switch', 
                    'title' => esc_html__('Play slideshow on single portfolio posts?', 'verve'),
                    'subtitle'=> esc_html__('Applicable only for posts with wide and half layout', 'verve'),
                    "default"       => 1,
                ), 
                array( 'id'=>'delay_portfolio', 
                    'type' => 'text', 
                    'title' => esc_html__('Slideshow delay in miliseconds', 'verve'), 
                    'subtitle' => esc_html__('Applicable only for posts with wide and half layout layout', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'validate' => 'numeric', 
                    'default' => '6500', 
                    'class' => 'small-text' 
                ),
                array(
                    'id'=>'uppercase_folio_headings',
                    'type' => 'switch', 
                    'title' => esc_html__('Uppercase titles?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 0,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'footer_port',
                    'type' => 'switch', 
                    'title' => esc_html__('Show footer on single portfolio posts?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 0,
                ),
                array(
                    'id'=>'dateby_port',
                    'type' => 'switch', 
                    'title' => esc_html__('Show date on single portfolio posts?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'categoriesby_port',
                    'type' => 'switch', 
                    'title' => esc_html__('Show skills on single portfolio posts?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'show_port_nav',
                    'type' => 'switch', 
                    'title' => esc_html__('Show previous and next posts link?', 'verve'),
                    'subtitle'=> esc_html__('Will be shown under the post content.', 'verve'),
                    "default"       => 0,
                ),
                 array(
                    'id'=>'related_port',
                    'type' => 'switch', 
                    'title' => esc_html__('Show related posts on single portfolio posts?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                 array(
                    'id'=>'linked_mfp',
                    'type' => 'switch', 
                    'title' => esc_html__('Enable link to portfolio single post on lightboxes?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 0,
                ), 
                /*array(
                    'id'=>'related_port_bk_color',
                    'type' => 'color',
                    'title' => esc_html__('Related posts background color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'related_port_border_color',
                    'type' => 'color',
                    'title' => esc_html__('Related posts border color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#ffffff',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),*/
                array(
                    'id'=>'backend_lb_overlayer',
                    'type' => 'info',
                    'desc' => esc_html__('Overlayer: will be shown above the content when a portfolio thumb is clicked', 'verve')
                ),
                array(
                    'id'=>'active_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer active text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#0ab6d1',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'headings_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer headings color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#2F2F2F',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                    ),
                array(
                    'id'=>'smallers_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer small headings text color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#A5A5A5',
                    'validate' => 'color',
                    'transparent' => false,
                    'compiler' => 'true'
                ),
                array(
                    'id'=>'body_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer body color', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'default' => '#404142',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'lines_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer divider lines color', 'verve'), 
                    'default' => '#E8E8E8',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                array(
                    'id'=>'background_color_overlayer',
                    'type' => 'color',
                    'title' => esc_html__('Overlayer background color', 'verve'), 
                    'default' => '#FFFFFF',
                    'validate' => 'color',
                    'transparent' => false,
                    ),
                /*array(
                    'id'=>'overlayer_opacity',
                    'type' => 'slider', 
                    'title' => esc_html__('Overlayer background opacity', 'verve'),
                    'desc'=> esc_html__('Min: 0, max: 100', 'verve'),
                    "default"       => "100",
                    "min"       => "0",
                    "step"      => "5",
                    "max"       => "100",
                ),*/
                array(
                    'id'=>'backend_lb_share_folio',
                    'type' => 'info',
                    'desc' => esc_html__('Social Sharing', 'verve')
                ),
                array(
                    'id'=>'share_portfolio',
                    'type' => 'switch', 
                    'title' => esc_html__('Show sharing buttons?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                ),
                array(
                    'id'=>'share_portfolio_fb',
                    'type' => 'checkbox',
                    'required' => array('share_portfolio','equals','1'), 
                    'title' => esc_html__('Facebook', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_portfolio_goo',
                    'type' => 'checkbox',
                    'required' => array('share_portfolio','equals','1'), 
                    'title' => esc_html__('Google +', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_portfolio_pin',
                    'type' => 'checkbox',
                    'required' => array('share_portfolio','equals','1'), 
                    'title' => esc_html__('Pinterest', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
                array(
                    'id'=>'share_portfolio_twt',
                    'type' => 'checkbox',
                    'required' => array('share_portfolio','equals','1'), 
                    'title' => esc_html__('Twitter', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => '1'
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-envelope',
            'icon_class' => 'icon-large',
            'title' => __('Google Maps API', 'verve'),
            'fields' => array(
                array( 
                    'id'=>'google_maps_key', 
                    'type' => 'text', 
                    'title' => __('Google API Key', 'verve'), 
                    'subtitle' => __('More info here https://developers.google.com/maps/pricing-and-plans/standard-plan-2016-update', 'verve'), 
                    'desc' => __('', 'verve'),
                    'default' => '', 
                    'class' => '' 
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-search',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Search Results', 'verve'),
            'fields' => array(
                array(
                'id'=>'search_image',
                'type' => 'media', 
                'title' => esc_html__('Header image', 'verve'),
                'compiler' => 'true',
                'default'=> array(
                    'url'=>'', 
                    'id'=>'', 
                    'width'=>'', 
                    'height'=>'',
                ),  
                'desc'=> esc_html__('Optional', 'verve'),
                'subtitle' => esc_html__('', 'verve'),
                'compiler' => 'true'
                ),
                array(
                    'id'=>'search_right_sidebar',
                    'type' => 'switch', 
                    'title' => esc_html__('Display right sidebar on search page?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                    'compiler' => 'true'
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-error',
            'icon_class' => 'icon-large',
            'title' => esc_html__('404 Error Page', 'verve'),
            'fields' => array(
                array(
                'id'=>'error_image',
                'type' => 'media', 
                'title' => esc_html__('Header image', 'verve'),
                'compiler' => 'true',
                'default'=> array(
                    'url'=>'', 
                    'id'=>'', 
                    'width'=>'', 
                    'height'=>'',
                ),  
                'desc'=> esc_html__('Optional', 'verve'),
                'subtitle' => esc_html__('', 'verve'),
                'compiler' => 'true'
                ),
                array(
                    'id'=>'404_search',
                    'type' => 'switch', 
                    'title' => esc_html__('Display search field on 404 page?', 'verve'),
                    'subtitle'=> esc_html__('', 'verve'),
                    "default"       => 1,
                    'compiler' => 'true'
                ),
            )
        );
        $verve_html=array('a' => array('href' => array(),'title' => array(),'style'=>array()),'p' => array('style'=>array()),'br' => array('style'=>array()),'em' => array('style'=>array()),'strong' => array('style'=>array()));
        if(function_exists('icl_object_id')) {
            $this->sections[] = array(
                'icon' => 'el-icon-globe',
                'icon_class' => 'icon-large',
                'title' => esc_html__('WPML', 'verve'),
                'fields' => array(
                    array(
                        'id'=>'verve_wpml_menu',
                        'type' => 'switch', 
                        'title' => esc_html__('Append languages menu to logo bar?', 'verve'),
                        'subtitle'=> wp_kses('WPML is a premium plugin that can be downloaded <a href="'.get_admin_url().'plugin-install.php?tab=commercial">here</a>.', $verve_html),
                        "default" => 1,
                    ),
                )
            );
        }
        if (class_exists('woocommerce')) {
            $this->sections[] = array(
                'icon' => 'el-icon-shopping-cart',
                'icon_class' => 'icon-large',
                'title' => esc_html__('Woocommerce', 'verve'),
                'fields' => array(
                    array( 
                        'id'=>'woo_subheading', 
                        'type' => 'text', 
                        'title' => esc_html__('Shop page subheadings', 'verve'), 
                        'subtitle' => esc_html__('Will be displayed under the shop page title', 'verve'), 
                        'desc' => esc_html__('Optional', 'verve'),
                        'default' => esc_html__('A stunning place to get your stuff the easy way.', 'verve'),
                    ),
                    array(
                        'id'=>'woo_col_nr',
                        'type' => 'select',
                        'title' => esc_html__('Number of products per row?', 'verve'), 
                        'subtitle' => esc_html__('Default value is Four.', 'verve'),
                        'desc' => esc_html__('', 'verve'),
                        'options' => array(
                            '2' => esc_html__('Two', 'verve'),
                            '3' => esc_html__('Three', 'verve'),
                            '4' => esc_html__('Four', 'verve')
                        ),
                        'default' => '4',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'woo_sidebar_display',
                        'type' => 'switch', 
                        'title' => esc_html__('Display right sidebar by default?', 'verve'),
                        'subtitle'=> esc_html__("This option will apply only to WooCommerce Core Pages that aren't set up using shortcodes. If you want to show/hide a sidebar on a specific page add ?sidebar=y or ?sidebar=n to your link URL", 'verve'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'woo_cart_display',
                        'type' => 'switch',
                        'title' => esc_html__('Add Shopping Cart info to the Logo Bar?', 'verve'),
                        'subtitle' => esc_html__('', 'verve'),
                        "default"       => 1,
                        'desc' => esc_html__('', 'verve'),
                    ),
                    array(
                        'id'=>'woo_cart_always_display',
                        'type' => 'switch', 
                        'title' => esc_html__('Show Shopping Cart info even when it is empty?', 'verve'),
                        'subtitle'=> esc_html__("", 'verve'),
                        "default"       => 0,
                        'required' => array('woo_cart_display','equals','1'), 
                    ),
                    /*array(
                        'id'=>'woo_cart_info',
                        'type' => 'select', 
                        'title' => esc_html__('Cart information?', 'verve'),
                        'subtitle'=> esc_html__("", 'verve'),
                        'options' => array('items' => esc_html__('Items', 'verve'),'price' => esc_html__('Price', 'verve'),'both' => esc_html__('Both', 'verve')),
                        'default' => array('price' => 'Price'),
                        'required' => array('woo_cart_display','equals','1'), 
                    ),*/
                    array(
                        'id'=>'backend_widgets_woocas_trans',
                        'type' => 'info',
                        'desc' => esc_html__('Cart Translations', 'verve')
                    ),
                    array( 
                        'id'=>'in_cart_text', 'type' => 'text', 
                        'title' => esc_html__('In cart text', 'verve'), 
                        'subtitle' => esc_html__('', 'verve'), 
                        'desc' => esc_html__('Example: 1 item in cart', 'verve'), 
                        'default' => esc_html__('IN CART', 'verve')
                    ),
                    array( 
                        'id'=>'no_items_text', 
                        'type' => 'text', 
                        'title' => esc_html__('Empty Cart Text', 'verve'), 
                        'subtitle' => esc_html__('', 'verve'), 
                        'desc' => esc_html__('', 'verve'),
                        'default' => esc_html__('YOUR CART IS EMPTY', 'verve')
                    ),
                )
            );
        }
        $this->sections[] = array(
            'icon' => 'el-icon-comment',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Translations', 'verve'),
            'fields' => array(
                array(
                    'id'=>'theme_translation',
                    'type' => 'switch', 
                    'title' => esc_html__('Translate using .mo files?', 'verve'),
                    'subtitle'=> esc_html__('If yes is selected the values below will be ignored. If WPML plugin is active the values below will be overriden too.', 'verve'),
                    "default" => 0,
                ),
                array(
                    'id'=>'backend_tr_general',
                    'type' => 'info',
                    'desc' => esc_html__('General', 'verve')
                ),
                array( 
                    'id'=>'theme_divider', 
                    'type' => 'text', 
                    'title' => esc_html__('Text separator', 'verve'), 
                    'subtitle' => esc_html__('Used on multiple parts of the theme to divide pieces of text', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('-','verve')
                ),
                array( 
                    'id'=>'search_tip_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Search field tip text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Search this website...','verve')
                ),
                array( 
                    'id'=>'submit_search_res_title', 
                    'type' => 'text', 
                    'title' => esc_html__('Search results page title text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Search Results for', 'verve')
                ),
                array( 
                    'id'=>'submit_search_no_results', 
                    'type' => 'text', 
                    'title' => esc_html__('Search results - no results found text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('No Results Found for', 'verve')
                ),
                array(
                    'id'=>'previous_text',
                    'type' => 'text',
                    'title' => esc_html__('Previous entries text', 'verve'),
                    'subtitle' => esc_html__('Will be used on navigation buttons', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Previous','verve')
                ),
                array(
                    'id'=>'next_text',
                    'type' => 'text',
                    'title' => esc_html__('Next entries text', 'verve'),
                    'subtitle' => esc_html__('Will be used on navigation buttons', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Next','verve')
                ),
                array( 
                    'id'=>'required_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Required text', 'verve'), 
                    'subtitle' => esc_html__('Used on mandatory fields.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__(' (required)', 'verve')
                ),
                array(
                    'id'=>'profile_text',
                    'type' => 'text',
                    'title' => esc_html__('Members view profile link text', 'verve'),
                    'subtitle' => esc_html__('Shown under each member image and description', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('View Profile', 'verve'),
                ),
                array( 
                    'id'=>'in_touch_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Get in touch text', 'verve'), 
                    'subtitle' => esc_html__('Used near team member social network buttons.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Get In touch', 'verve')
                ),
                /*array( 
                    'id'=>'filter_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Filter text', 'verve'), 
                    'subtitle' => esc_html__('Used on blog and portfolio filter buttons.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Filter', 'verve')
                ),*/
                array(
                    'id'=>'backend_tr_error_page',
                    'type' => 'info',
                    'desc' => esc_html__('404 Error Page', 'verve')
                ),
                array( 
                    'id'=>'404_title_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Page title text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('NOT FOUND','verve')
                ),
                array(
                    'id'=>'404_body_text',
                    'type' => 'textarea',
                    'title' => esc_html__('Page body text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'),
                    'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                    'default' => esc_html__('Ooops... You ventured into the Great Desert! Lets try again, ok?','verve')
                ),
                array(
                    'id'=>'backend_tr_blog',
                    'type' => 'info',
                    'desc' => esc_html__('Blog', 'verve')
                ),
                array( 
                    'id'=>'read_more', 
                    'type' => 'text', 
                    'title' => esc_html__('Read more button text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Read More', 'verve')
                ),
                array( 
                    'id'=>'sticky_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Sticky post text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Sticky Post', 'verve')
                ),
                array( 
                    'id'=>'min_read_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Minutes read text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('MIN READ', 'verve')
                ),
                array( 
                    'id'=>'posted_by_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Posted by text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Posted by', 'verve')
                ),
                array(
                    'id'=>'on_text',
                    'type' => 'text',
                    'title' => esc_html__('On text', 'verve'),
                    'subtitle' => esc_html__('Will be used on some blog sentences.', 'verve'),
                    'desc' => esc_html__('Example: Posted on Jan 13th.', 'verve'),
                    'default' => esc_html__('on','verve')
                ),
                array( 
                    'id'=>'about_author_text', 
                    'type' => 'text', 
                    'title' => esc_html__('About text', 'verve'), 
                    'subtitle' => esc_html__('Displayed before post author name.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('About', 'verve')
                ),
                array( 
                    'id'=>'to_blog', 
                    'type' => 'text', 
                    'title' => esc_html__('Back to Blog button text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('To Blog', 'verve')
                ),
                array( 
                    'id'=>'older', 
                    'type' => 'text', 
                    'title' => esc_html__('Older posts text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on parent blog pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Older posts', 'verve')
                ),
                array( 
                    'id'=>'newer', 
                    'type' => 'text', 
                    'title' => esc_html__('Newer posts text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on parent blog pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Newer posts', 'verve')
                ),
                array( 
                    'id'=>'related_posts_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - related posts text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Related News', 'verve')
                ),
                array( 
                    'id'=>'related_posts_teaser_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - related posts sub-heading text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Other posts that you should not miss', 'verve')
                ),
                array( 
                    'id'=>'older_single', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - previous post text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on single post pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('PREVIOUS POST', 'verve')
                ),
                array( 
                    'id'=>'newer_single', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - next post text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on single post pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('NEXT POST', 'verve')
                ),
                array( 
                    'id'=>'all_the_posts', 
                    'type' => 'text', 
                    'title' => esc_html__('Archives pages', 'verve'), 
                    'subtitle' => esc_html__('Subheading text', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('All the posts published', 'verve')
                ),
                array(
                    'id'=>'backend_tr_portfolio',
                    'type' => 'info',
                    'desc' => esc_html__('Portfolio', 'verve')
                ),
                array(
                    'id'=>'prj_desc_text',
                    'type' => 'text',
                    'title' => esc_html__('Project description text', 'verve'),
                    'subtitle' => esc_html__('Will be displayed just above the project text.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('About this project','verve')
                ),
                array(
                    'id'=>'date_text',
                    'type' => 'text',
                    'title' => esc_html__('Date text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Date','verve')
                ),
                array(
                    'id'=>'client_text',
                    'type' => 'text',
                    'title' => esc_html__('Client description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Client','verve')
                ),
                array(
                    'id'=>'extra_fld1',
                    'type' => 'text',
                    'title' => esc_html__('Extra field 1 - Description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('My Custom Field 1','verve')
                ),
                array(
                    'id'=>'extra_fld2',
                    'type' => 'text',
                    'title' => esc_html__('Extra field 2 - Description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('My Custom Field 2','verve')
                ),
                array(
                    'id'=>'extra_fld3',
                    'type' => 'text',
                    'title' => esc_html__('Extra field 3 - Description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('My Custom Field 3','verve')
                ),
                array(
                    'id'=>'skills_text',
                    'type' => 'text',
                    'title' => esc_html__('Category description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Skills','verve')
                ),
                array(
                    'id'=>'tags_text',
                    'type' => 'text',
                    'title' => esc_html__('Tag description text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Tags','verve')
                ),
                array(
                    'id'=>'project_text',
                    'type' => 'text',
                    'title' => esc_html__('Project link header text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Project URL','verve')
                ),
                array(
                    'id'=>'launch_text',
                    'type' => 'text',
                    'title' => esc_html__('Project link button text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Launch Project','verve')
                ),
                /*array(
                    'id'=>'prj_info_text',
                    'type' => 'text',
                    'title' => esc_html__('Open project text', 'verve'),
                    'subtitle' => esc_html__('', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Open Project','verve')
                ),*/
                array( 
                    'id'=>'all_text', 
                    'type' => 'text', 
                    'title' => esc_html__('All text', 'verve'), 
                    'subtitle' => esc_html__('Used on filters. Will show all posts on current page.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('All', 'verve')
                ),
                array( 
                    'id'=>'load_more', 
                    'type' => 'text', 
                    'title' => esc_html__('Load more posts text', 'verve'), 
                    'subtitle' => esc_html__('Will be shown under the posts grid.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('LOAD MORE POSTS', 'verve')
                ),
                array( 
                    'id'=>'no_more', 
                    'type' => 'text', 
                    'title' => esc_html__('No more posts to show text', 'verve'), 
                    'subtitle' => esc_html__('Will be shown under the posts grid.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('NO MORE POSTS TO SHOW', 'verve')
                ),
                array( 
                    'id'=>'related_prj_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Related projects text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Related Projects', 'verve')
                ),
                array( 
                    'id'=>'related_prj_teaser_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Related projects sub-heading text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Simply delivering amazing stuff', 'verve')
                ),
                array( 
                    'id'=>'to_portfolio', 
                    'type' => 'text', 
                    'title' => esc_html__('Back to Portfolio button text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('BACK TO PORTFOLIO', 'verve')
                ),
                array( 
                    'id'=>'prj_prev_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - previous post text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on single post pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Previous', 'verve')
                ),
                array( 
                    'id'=>'prj_next_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Single posts pages - next post text', 'verve'), 
                    'subtitle' => esc_html__('Used for navigation on single post pages.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Next', 'verve')
                ),
                /*array( 
                    'id'=>'prj_close_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Close lightbox text', 'verve'), 
                    'subtitle' => esc_html__('Used when the portfolio lightbox is opened.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('CLOSE', 'verve')
                ),*/
                array( 
                    'id'=>'all_the_portfolios', 
                    'type' => 'text', 
                    'title' => esc_html__('Archives pages', 'verve'), 
                    'subtitle' => esc_html__('Subheading text', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('All the work completed', 'verve')
                ),
                array(
                    'id'=>'backend_tr_comments',
                    'type' => 'info',
                    'desc' => esc_html__('Comments Section', 'verve')
                ),
                array( 
                    'id'=>'comments_label', 'type' => 'text', 
                    'title' => esc_html__('Comments title text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Comments', 'verve')
                ),
                array( 
                    'id'=>'comments_no_response', 
                    'type' => 'text', 
                    'title' => esc_html__('Zero comments text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('No comments', 'verve')
                ),
                array( 
                    'id'=>'comments_one_response', 
                    'type' => 'text', 
                    'title' => esc_html__('One comment text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('1 Comment', 'verve')
                ),
                array( 
                    'id'=>'comments_oneplus_response', 
                    'type' => 'text', 
                    'title' => esc_html__('Multiple comments text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Comments', 'verve')
                ),
                array(
                    'id'=>'backend_tr_respond',
                    'type' => 'info',
                    'desc' => esc_html__('Respond Section', 'verve')
                ),
                array( 
                    'id'=>'reply_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Reply text', 'verve'), 
                    'subtitle' => esc_html__('Used on buttons.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Reply', 'verve')
                ),
                array( 
                    'id'=>'comments_leave_reply', 
                    'type' => 'text', 
                    'title' => esc_html__('Text to ask the user to leave a reply', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Leave a Comment', 'verve')
                ),
                array( 
                    'id'=>'comments_under_reply', 
                    'type' => 'text', 
                    'title' => esc_html__('Compementary text shown under the leave a reply text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Your feedback is valuable for us. Your email will not be published.', 'verve')
                ),
                array( 
                    'id'=>'comments_author_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Name input field text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside the author input textfield.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Name', 'verve')
                ),
                array( 
                    'id'=>'comments_email_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Email input field text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside the email input textfield.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Email', 'verve')
                ),
                array( 
                    'id'=>'comments_url_text', 
                    'type' => 'text', 
                    'title' => esc_html__('URL input field text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside the URL input textfield.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Website', 'verve')
                ),
                array( 
                    'id'=>'comments_comment_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Comment input textarea text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside the comment input textarea.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Your comment', 'verve')
                ),
                array( 
                    'id'=>'comments_submit', 
                    'type' => 'text', 
                    'title' => esc_html__('Submit comment button text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Submit Comment &rarr;', 'verve')
                ),
                array( 
                    'id'=>'empty_text_error', 
                    'type' => 'text', 
                    'title' => esc_html__('Empty text error message', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Error! This field is required.', 'verve')
                ),
                array( 
                    'id'=>'invalid_email_error', 
                    'type' => 'text', 
                    'title' => esc_html__('Invalid email error message', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Error! Invalid email.', 'verve')
                ),
                array( 'id'=>'comment_ok_message', 
                    'type' => 'text', 
                    'title' => esc_html__('Comment submitted text', 'verve'), 
                    'subtitle' => esc_html__('This text is displayed after the comment is submitted.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Thank you for your feedback!', 'verve')
                ),
                array(
                    'id'=>'backend_tr_respond',
                    'type' => 'info',
                    'desc' => esc_html__('Contact Page', 'verve')
                ),
                array( 
                    'id'=>'contact_subject_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Subject help text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside of the subject input textfield. The name and email fields are the same as defined before for the comments section.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Subject', 'verve')
                ),
                array( 
                    'id'=>'contact_message_text', 
                    'type' => 'text', 'title' => esc_html__('Message help text', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed inside of the message input textfield.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Your message', 'verve')
                ),
                array( 
                    'id'=>'contact_submit', 
                    'type' => 'text', 'title' => esc_html__('Submit button text', 'verve'), 
                    'subtitle' => esc_html__('', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Send Message &rarr;','verve')
                ),
                array( 
                    'id'=>'contact_error_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Error message for empty field', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed when a mandatory input field is empty.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Error! This field is required.', 'verve')
                ),
                array( 
                    'id'=>'contact_error_email_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Error message for invalid email', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed when the entered email is invalid.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Error! This email is not valid.', 'verve')
                ),
                array( 
                    'id'=>'contact_wait_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Form submission: Wait message', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed right after the send message button is clicked and only until the email is sent.', 'verve'), 
                    'desc' => esc_html__('', 'verve'), 
                    'default' => esc_html__('Please wait...', 'verve')
                ),
                array( 
                    'id'=>'contact_ok_text', 
                    'type' => 'text', 
                    'title' => esc_html__('Form submission: Ok message', 'verve'), 
                    'subtitle' => esc_html__('This text will be displayed after sending the email.', 'verve'), 
                    'desc' => esc_html__('', 'verve'),
                    'default' => esc_html__('Thank you for contacting us. We will reply soon!', 'verve')
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-wrench',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Custom Scripts', 'verve'),
            'fields' => array(
                array(
                    'id'=>'css_text',
                    'type' => 'ace_editor',
                    'mode'     => 'css',
                    'theme'    => 'monokai',
                    'title' => esc_html__('Custom CSS', 'verve'), 
                    'subtitle' => esc_html__('Quickly add some CSS to your theme by adding it to this block.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'default'       => '',
                    'validate' => 'css',
                ),
                array(
                    'id'=>'js_text',
                    'type' => 'ace_editor',
                    'mode'     => 'javascript',
                    'theme'    => 'monokai',
                    'title' => esc_html__('Custom Javascript', 'verve'), 
                    'subtitle' => esc_html__('Add some js scripting here', 'verve'),
                    'desc' => "For object targeting use 'jQuery' prefix instead of the default '$' notation.",
                ),
            )
        );
        $this->sections[] = array(
            'icon' => 'el-icon-key',
            'icon_class' => 'icon-large',
            'title' => esc_html__('Advanced settings', 'verve'),
            'fields' => array(
                array(
                    'id'=>'info_warning_slugs',
                    'type'=>'info',
                    'style'=>'warning',
                    'header'=> esc_html__( 'This is a header.','verve'),
                    'desc' => esc_html__( "If slug changes don't apply immediately it is related to WordPress permalinks. After making your changes here you need to go to Settings>Reading and change permalinks structure to default. Save changes and then revert it to previous state.", 'verve')
                ),
                array(
                    'id'=>'portfolio_slug',
                    'type' => 'text',
                    'title' => esc_html__('Portfolios slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'portfolios'
                    ),
                array(
                    'id'=>'skills_slug',
                    'type' => 'text',
                    'title' => esc_html__('Skills slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('Portfolio hierarchical category', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'skills'
                    ),
                array(
                    'id'=>'folio_tags_slug',
                    'type' => 'text',
                    'title' => esc_html__('Portfolio tag slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('Portfolio non-hierarchical category', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'tagged'
                    ),
                array(
                    'id'=>'slides_slug',
                    'type' => 'text',
                    'title' => esc_html__('Slides slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'slides'
                    ),
                array(
                    'id'=>'groups_slug',
                    'type' => 'text',
                    'title' => esc_html__('Slides groups slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('Slides hierarchical category', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'group'
                    ),
                array(
                    'id'=>'members_slug',
                    'type' => 'text',
                    'title' => esc_html__('Members slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'member'
                    ),
                array(
                    'id'=>'team_slug',
                    'type' => 'text',
                    'title' => esc_html__('Team slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('Members hierarchical category', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'team'
                    ),
                array(
                    'id'=>'testimonials_slug',
                    'type' => 'text',
                    'title' => esc_html__('Testimonials slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'testimonials'
                    ),
                array(
                    'id'=>'testimonials_groups_slug',
                    'type' => 'text',
                    'title' => esc_html__('Testimonials groups slug', 'verve'),
                    'subtitle' => esc_html__('No special characters and must be unique.', 'verve'),
                    'desc' => esc_html__('Testimonials hierarchical category', 'verve'),
                    'validate' => 'no_special_chars',
                    'default' => 'testimonials_group'
                    ),
                array(
                    'id'=>'backend_tr_vc_light',
                    'type' => 'info',
                    'desc' => esc_html__('Visual Composer integration.', 'verve')
                ),
                array(
                    'id'=>'verve_light_vc',
                    'type' => 'switch', 
                    'title' => esc_html__('Use light version of Visual Composer?', 'verve'),
                    'subtitle'=> esc_html__("It is strongly recommended that you keep this option ON. If you decide to use the theme Visual Composer regular/heavy version, the website load speed will be higher and some of the elements may not work properly.", 'verve'),
                    "default"       => 1,
                ),
            )
        );

            $this->sections[] = array(
                'title'     => esc_html__('Import / Export', 'redux-framework-demo'),
                'desc'      => esc_html__('Import and Export your Redux Framework settings from file, text or URL.', 'redux-framework-demo'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => esc_html__('Import Export', 'redux-framework-demo'),
                        'subtitle'      => esc_html__('Save and restore your Redux options', 'redux-framework-demo'),
                        'full_width'    => false,
                    ),
                ),
            );                     
                    
            $this->sections[] = array(
                'type' => 'divide',
            );

            $this->sections[] = array(
                'icon'      => 'el-icon-info-sign',
                'title'     => esc_html__('Theme Information', 'redux-framework-demo'),
                'desc'      => esc_html__('<p class="description">Verve - Hybrid WordPress Theme</p>', 'redux-framework-demo'),
                'fields'    => array(
                    array(
                        'id'        => 'opt-raw-info',
                        'type'      => 'raw',
                        'content'   => $item_info,
                    )
                ),
            );

            if (false) {
                $tabs['docs'] = array(
                    'icon'      => 'el-icon-book',
                    'title'     => esc_html__('Documentation', 'redux-framework-demo'),
                    'content'   => nl2br('README.html')
                );
            }
        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => esc_html__('Theme Information 1', 'redux-framework-demo'),
                'content'   => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => esc_html__('Theme Information 2', 'redux-framework-demo'),
                'content'   => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = esc_html__('<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo');
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'          => 'prk_verve_options',            // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'      => esc_html__("Theme Control Panel","verve"),
                'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
                'menu_type'         => 'menu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
                'menu_title'        => esc_html__('Theme Options', 'redux-framework-demo'),
                'page_title'        => esc_html__('Theme Options', 'redux-framework-demo'),
                
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '', // Must be defined to add google fonts to the typography module
                
                'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
                'admin_bar'         => true,                    // Show the panel pages on the admin bar
                'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
                'dev_mode'          => false,                    // Show the time the page took to load, etc
                'customizer'        => true,                    // Enable basic customizer support
                
                // OPTIONAL -> Give you extra features
                'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
                'menu_icon'         => '',                      // Specify a custom URL to an icon
                'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
                'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
                'page_slug'         => '_options',              // Page slug used to denote the panel
                'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
                'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
                'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,                   // Shows the Import/Export panel when not used as a field.
                
                // CAREFUL -> These options are for advanced use only
                'transient_time'    => 60 * MINUTE_IN_SECONDS,
                'output'            => false,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
                
                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'           => false, // REMOVE

                // HINTS
                'hints' => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'         => 'light',
                        'shadow'        => true,
                        'rounded'       => false,
                        'style'         => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show'          => array(
                            'effect'        => 'slide',
                            'duration'      => '500',
                            'event'         => 'mouseover',
                        ),
                        'hide'      => array(
                            'effect'    => 'slide',
                            'duration'  => '500',
                            'event'     => 'click mouseleave',
                        ),
                    ),
                )
            );

            // Add content after the form.
            $this->args['footer_text'] = esc_html__('','verve');
        }

    }
    
    global $reduxConfig;
    $reduxConfig = new verve_options_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')):
    function redux_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')):
    function redux_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
